@@ -6,4 +6,4 @@ curl -sL https://raw.githubusercontent.com/tokuhirom/Perl-Build/master/perl-buil
 perl /tmp/perl-build "$PERL_VERSION" /opt/
 curl -sL https://cpanmin.us | /opt/bin/perl - App::cpanminus
 /opt/bin/cpanm -n .
-cp bin/bootstrap /opt/
+cp script/bootstrap /opt/
